tiled.adapters.tiff.TiffAdapter
===============================

.. currentmodule:: tiled.adapters.tiff

.. autoclass:: TiffAdapter

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~TiffAdapter.__init__
      ~TiffAdapter.macrostructure
      ~TiffAdapter.microstructure
      ~TiffAdapter.read
      ~TiffAdapter.read_block
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
   
      ~TiffAdapter.metadata
      ~TiffAdapter.structure_family
   
   